version = "1.29"

# tools
dblatex = ''
fop = ''
highlight = '/usr/bin/source-highlight'
highlight_options = '-t4 -s$SRC_LANG -cstyle.css --no-doc -i'
pkg_config = '/usr/bin/pkg-config'
xsltproc = '/usr/bin/xsltproc'

# configured directories
prefix = '/usr/local'
datarootdir = "${prefix}/share".replace('${prefix}', prefix)
datadir = "${datarootdir}".replace('${datarootdir}', datarootdir)

exeext = ''
